@@ -28,7 +28,7 @@ use UI::Dialog::Backend;
 BEGIN {
   use vars qw( $VERSION @ISA );
   @ISA = qw( UI::Dialog::Backend );
-  $VERSION = '1.12';
+  $VERSION = '1.13';
 }
 
 #::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
@@ -622,7 +622,6 @@ sub menu {
 
   my $fmt = $self->prepare_format($args);
   $fmt = $self->append_format_base($args,$fmt);
-  $fmt = $self->append_format($fmt,'--separate-output');
   $fmt = $self->append_format($fmt,'--menu');
   $fmt = $self->append_format($fmt,'{{text}} {{height}} {{width}} {{listheight}} {{list}}');
   my $command = $self->prepare_command
@@ -676,21 +675,6 @@ sub checklist {
       text => $self->make_kvt($args,$args->{'text'}),
     );
 
-  if ($args->{'list'}) {
-		$args->{'list'} = [ ' ', [' ', 1] ] unless ref($args->{'list'}) eq "ARRAY";
-		my ($item,$info);
-		while (@{$args->{'list'}}) {
-			$item = shift(@{$args->{'list'}});
-			$info = shift(@{$args->{'list'}});
-			$command .= ' "'.($item||' ').'" "'.($info->[0]||' ').'" "'.(($info->[1]) ? 'on' : 'off').'"';
-		}
-  }
-  else {
-		$args->{'items'} = [ ' ', ' ', 'off' ] unless ref($args->{'items'}) eq "ARRAY";
-		foreach my $item (@{$args->{'items'}}) {
-			$command .= ' "' . ($item|' ') . '"';
-		}
-  }
   my ($rv,$selected) = $self->command_array($command);
   $self->rs('null');
   my $this_rv;
